==> jboss-eap-7.2.9-src.zip: jboss-eap-7.2-src/clustering/server/src/main/java/org/wildfly/clustering/server/singleton/DistributedSingletonServiceContext.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.server.singleton;

import java.util.function.Supplier;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.dispatcher.CommandDispatcherFactory;
import org.wildfly.clustering.provider.ServiceProviderRegistry;
import org.wildfly.clustering.service.ServiceNameProvider;
import org.wildfly.clustering.singleton.SingletonElectionPolicy;

/**
 * @author Paul Ferraro
 */
public interface DistributedSingletonServiceContext extends ServiceNameProvider {
    Supplier<ServiceProviderRegistry<ServiceName>> getServiceProviderRegistry();
    Supplier<CommandDispatcherFactory> getCommandDispatcherFactory();
    SingletonElectionPolicy getElectionPolicy();
    int getQuorum();
}

==> jboss-eap-7.3.1-src.zip: jboss-eap-7.3-src/clustering/server/src/main/java/org/wildfly/clustering/server/singleton/DistributedSingletonServiceContext.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.server.singleton;

import java.util.function.Supplier;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.dispatcher.CommandDispatcherFactory;
import org.wildfly.clustering.provider.ServiceProviderRegistry;
import org.wildfly.clustering.singleton.SingletonElectionPolicy;

/**
 * @author Paul Ferraro
 */
public interface DistributedSingletonServiceContext extends SingletonServiceContext {
    Supplier<ServiceProviderRegistry<ServiceName>> getServiceProviderRegistry();
    Supplier<CommandDispatcherFactory> getCommandDispatcherFactory();
    SingletonElectionPolicy getElectionPolicy();
    int getQuorum();
}
